@@ -44,6 +44,7 @@ from .paginator import (
 )
 from .type_defs import (
     ApplyPendingMaintenanceActionResponseTypeDef,
+    BatchStartRecommendationsResponseTypeDef,
     CancelReplicationTaskAssessmentRunResponseTypeDef,
     CreateEndpointResponseTypeDef,
     CreateEventSubscriptionResponseTypeDef,
@@ -76,6 +77,8 @@ from .type_defs import (
     DescribeFleetAdvisorSchemasResponseTypeDef,
     DescribeOrderableReplicationInstancesResponseTypeDef,
     DescribePendingMaintenanceActionsResponseTypeDef,
+    DescribeRecommendationLimitationsResponseTypeDef,
+    DescribeRecommendationsResponseTypeDef,
     DescribeRefreshSchemasStatusResponseTypeDef,
     DescribeReplicationInstancesResponseTypeDef,
     DescribeReplicationInstanceTaskLogsResponseTypeDef,
@@ -111,12 +114,14 @@ from .type_defs import (
     OracleSettingsTypeDef,
     PostgreSQLSettingsTypeDef,
     RebootReplicationInstanceResponseTypeDef,
+    RecommendationSettingsTypeDef,
     RedisSettingsTypeDef,
     RedshiftSettingsTypeDef,
     RefreshSchemasResponseTypeDef,
     ReloadTablesResponseTypeDef,
     RunFleetAdvisorLsaAnalysisResponseTypeDef,
     S3SettingsTypeDef,
+    StartRecommendationsRequestEntryTypeDef,
     StartReplicationTaskAssessmentResponseTypeDef,
     StartReplicationTaskAssessmentRunResponseTypeDef,
     StartReplicationTaskResponseTypeDef,
@@ -205,7 +210,8 @@ class DatabaseMigrationServiceClient(BaseClient):
         self, *, ResourceArn: str, Tags: Sequence[TagTypeDef]
     ) -> Dict[str, Any]:
         """
-        .
+        Adds metadata tags to an DMS resource, including replication instance, endpoint,
+        subnet group, and migration task.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.add_tags_to_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#add_tags_to_resource)
@@ -222,6 +228,17 @@ class DatabaseMigrationServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#apply_pending_maintenance_action)
         """
 
+    def batch_start_recommendations(
+        self, *, Data: Sequence[StartRecommendationsRequestEntryTypeDef] = ...
+    ) -> BatchStartRecommendationsResponseTypeDef:
+        """
+        Starts the analysis of up to 20 source databases to recommend target engines for
+        each source database.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.batch_start_recommendations)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#batch_start_recommendations)
+        """
+
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
@@ -287,7 +304,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         GcpMySQLSettings: GcpMySQLSettingsTypeDef = ...
     ) -> CreateEndpointResponseTypeDef:
         """
-        .
+        Creates an endpoint using the provided settings.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.create_endpoint)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#create_endpoint)
@@ -386,7 +403,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         ResourceIdentifier: str = ...
     ) -> CreateReplicationTaskResponseTypeDef:
         """
-        .
+        Creates a replication task using the specified parameters.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.create_replication_task)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#create_replication_task)
@@ -412,7 +429,7 @@ class DatabaseMigrationServiceClient(BaseClient):
 
     def delete_endpoint(self, *, EndpointArn: str) -> DeleteEndpointResponseTypeDef:
         """
-        .
+        Deletes the specified endpoint.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.delete_endpoint)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#delete_endpoint)
@@ -472,7 +489,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         self, *, ReplicationTaskArn: str
     ) -> DeleteReplicationTaskResponseTypeDef:
         """
-        .
+        Deletes the specified replication task.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.delete_replication_task)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#delete_replication_task)
@@ -561,7 +578,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         self, *, Filters: Sequence[FilterTypeDef] = ..., MaxRecords: int = ..., Marker: str = ...
     ) -> DescribeEndpointsResponseTypeDef:
         """
-        .
+        Returns information about the endpoints for your account in the current region.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.describe_endpoints)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#describe_endpoints)
@@ -571,7 +588,8 @@ class DatabaseMigrationServiceClient(BaseClient):
         self, *, SourceType: str = ..., Filters: Sequence[FilterTypeDef] = ...
     ) -> DescribeEventCategoriesResponseTypeDef:
         """
-        .
+        Lists categories for all event source types, or, if specified, for a specified
+        source type.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.describe_event_categories)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#describe_event_categories)
@@ -691,6 +709,28 @@ class DatabaseMigrationServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#describe_pending_maintenance_actions)
         """
 
+    def describe_recommendation_limitations(
+        self, *, Filters: Sequence[FilterTypeDef] = ..., MaxRecords: int = ..., NextToken: str = ...
+    ) -> DescribeRecommendationLimitationsResponseTypeDef:
+        """
+        Returns a paginated list of limitations for recommendations of target Amazon Web
+        Services engines.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.describe_recommendation_limitations)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#describe_recommendation_limitations)
+        """
+
+    def describe_recommendations(
+        self, *, Filters: Sequence[FilterTypeDef] = ..., MaxRecords: int = ..., NextToken: str = ...
+    ) -> DescribeRecommendationsResponseTypeDef:
+        """
+        Returns a paginated list of target engine recommendations for your source
+        databases.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.describe_recommendations)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#describe_recommendations)
+        """
+
     def describe_refresh_schemas_status(
         self, *, EndpointArn: str
     ) -> DescribeRefreshSchemasStatusResponseTypeDef:
@@ -773,7 +813,8 @@ class DatabaseMigrationServiceClient(BaseClient):
         WithoutSettings: bool = ...
     ) -> DescribeReplicationTasksResponseTypeDef:
         """
-        .
+        Returns information about replication tasks for your account in the current
+        region.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.describe_replication_tasks)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#describe_replication_tasks)
@@ -838,7 +879,8 @@ class DatabaseMigrationServiceClient(BaseClient):
         self, *, ResourceArn: str = ..., ResourceArnList: Sequence[str] = ...
     ) -> ListTagsForResourceResponseTypeDef:
         """
-        .
+        Lists all metadata tags attached to an DMS resource, including replication
+        instance, endpoint, subnet group, and migration task.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#list_tags_for_resource)
@@ -882,7 +924,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         GcpMySQLSettings: GcpMySQLSettingsTypeDef = ...
     ) -> ModifyEndpointResponseTypeDef:
         """
-        .
+        Modifies the specified endpoint.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.modify_endpoint)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#modify_endpoint)
@@ -955,7 +997,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         TaskData: str = ...
     ) -> ModifyReplicationTaskResponseTypeDef:
         """
-        .
+        Modifies the specified replication task.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.modify_replication_task)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#modify_replication_task)
@@ -965,7 +1007,8 @@ class DatabaseMigrationServiceClient(BaseClient):
         self, *, ReplicationTaskArn: str, TargetReplicationInstanceArn: str
     ) -> MoveReplicationTaskResponseTypeDef:
         """
-        .
+        Moves a replication task from its current replication instance to a different
+        target replication instance using the specified parameters.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.move_replication_task)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#move_replication_task)
@@ -1013,7 +1056,8 @@ class DatabaseMigrationServiceClient(BaseClient):
         self, *, ResourceArn: str, TagKeys: Sequence[str]
     ) -> Dict[str, Any]:
         """
-        .
+        Removes metadata tags from an DMS resource, including replication instance,
+        endpoint, subnet group, and migration task.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.remove_tags_from_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#remove_tags_from_resource)
@@ -1028,6 +1072,17 @@ class DatabaseMigrationServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#run_fleet_advisor_lsa_analysis)
         """
 
+    def start_recommendations(
+        self, *, DatabaseId: str, Settings: RecommendationSettingsTypeDef
+    ) -> EmptyResponseMetadataTypeDef:
+        """
+        Starts the analysis of your source database to provide recommendations of target
+        engines.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.start_recommendations)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#start_recommendations)
+        """
+
     def start_replication_task(
         self,
         *,
@@ -1038,7 +1093,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         CdcStopPosition: str = ...
     ) -> StartReplicationTaskResponseTypeDef:
         """
-        .
+        Starts the replication task.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.start_replication_task)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#start_replication_task)
@@ -1048,7 +1103,8 @@ class DatabaseMigrationServiceClient(BaseClient):
         self, *, ReplicationTaskArn: str
     ) -> StartReplicationTaskAssessmentResponseTypeDef:
         """
-        .
+        Starts the replication task assessment for unsupported data types in the source
+        database.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.start_replication_task_assessment)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#start_replication_task_assessment)
@@ -1079,7 +1135,7 @@ class DatabaseMigrationServiceClient(BaseClient):
         self, *, ReplicationTaskArn: str
     ) -> StopReplicationTaskResponseTypeDef:
         """
-        .
+        Stops the replication task.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Client.stop_replication_task)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/client/#stop_replication_task)
