@@ -31,6 +31,7 @@ from .literals import (
     EncodingTypeValueType,
     EncryptionModeValueType,
     EndpointSettingTypeValueType,
+    KafkaSaslMechanismType,
     KafkaSecurityProtocolType,
     MessageFormatValueType,
     MigrationTypeValueType,
@@ -39,12 +40,14 @@ from .literals import (
     PluginNameValueType,
     RedisAuthTypeValueType,
     RefreshSchemasStatusTypeValueType,
+    ReleaseStatusValuesType,
     ReloadOptionValueType,
     ReplicationEndpointTypeValueType,
     SafeguardPolicyType,
     SslSecurityProtocolValueType,
     StartReplicationTaskTypeValueType,
     TargetDbTypeType,
+    TlogAccessModeType,
     VersionStatusType,
 )
 
@@ -64,6 +67,7 @@ __all__ = (
     "ApplyPendingMaintenanceActionMessageRequestTypeDef",
     "ResponseMetadataTypeDef",
     "AvailabilityZoneTypeDef",
+    "BatchStartRecommendationsErrorEntryTypeDef",
     "CancelReplicationTaskAssessmentRunMessageRequestTypeDef",
     "CertificateTypeDef",
     "CollectorHealthCheckTypeDef",
@@ -117,6 +121,7 @@ __all__ = (
     "FleetAdvisorSchemaObjectResponseTypeDef",
     "DescribeOrderableReplicationInstancesMessageRequestTypeDef",
     "OrderableReplicationInstanceTypeDef",
+    "LimitationTypeDef",
     "DescribeRefreshSchemasStatusMessageRequestTypeDef",
     "RefreshSchemasStatusTypeDef",
     "DescribeReplicationInstanceTaskLogsMessageRequestTypeDef",
@@ -133,7 +138,10 @@ __all__ = (
     "ModifyReplicationTaskMessageRequestTypeDef",
     "MoveReplicationTaskMessageRequestTypeDef",
     "PendingMaintenanceActionTypeDef",
+    "RdsConfigurationTypeDef",
+    "RdsRequirementsTypeDef",
     "RebootReplicationInstanceMessageRequestTypeDef",
+    "RecommendationSettingsTypeDef",
     "RefreshSchemasMessageRequestTypeDef",
     "TableToReloadTypeDef",
     "RemoveTagsFromResourceMessageRequestTypeDef",
@@ -165,6 +173,7 @@ __all__ = (
     "RunFleetAdvisorLsaAnalysisResponseTypeDef",
     "UpdateSubscriptionsToEventBridgeResponseTypeDef",
     "SubnetTypeDef",
+    "BatchStartRecommendationsResponseTypeDef",
     "DeleteCertificateResponseTypeDef",
     "DescribeCertificatesResponseTypeDef",
     "ImportCertificateResponseTypeDef",
@@ -192,6 +201,8 @@ __all__ = (
     "DescribeFleetAdvisorSchemaObjectSummaryRequestRequestTypeDef",
     "DescribeFleetAdvisorSchemasRequestRequestTypeDef",
     "DescribePendingMaintenanceActionsMessageRequestTypeDef",
+    "DescribeRecommendationLimitationsRequestRequestTypeDef",
+    "DescribeRecommendationsRequestRequestTypeDef",
     "DescribeReplicationInstancesMessageRequestTypeDef",
     "DescribeReplicationSubnetGroupsMessageRequestTypeDef",
     "DescribeReplicationTaskAssessmentRunsMessageRequestTypeDef",
@@ -226,6 +237,7 @@ __all__ = (
     "DescribeFleetAdvisorLsaAnalysisResponseTypeDef",
     "DescribeFleetAdvisorSchemaObjectSummaryResponseTypeDef",
     "DescribeOrderableReplicationInstancesResponseTypeDef",
+    "DescribeRecommendationLimitationsResponseTypeDef",
     "DescribeRefreshSchemasStatusResponseTypeDef",
     "RefreshSchemasResponseTypeDef",
     "DescribeReplicationInstanceTaskLogsResponseTypeDef",
@@ -233,6 +245,9 @@ __all__ = (
     "DescribeReplicationTaskIndividualAssessmentsResponseTypeDef",
     "DescribeTableStatisticsResponseTypeDef",
     "ResourcePendingMaintenanceActionsTypeDef",
+    "RdsRecommendationTypeDef",
+    "StartRecommendationsRequestEntryTypeDef",
+    "StartRecommendationsRequestRequestTypeDef",
     "ReloadTablesMessageRequestTypeDef",
     "ReplicationTaskAssessmentRunTypeDef",
     "ReplicationTaskTypeDef",
@@ -246,6 +261,8 @@ __all__ = (
     "DescribeFleetAdvisorDatabasesResponseTypeDef",
     "ApplyPendingMaintenanceActionResponseTypeDef",
     "DescribePendingMaintenanceActionsResponseTypeDef",
+    "RecommendationDataTypeDef",
+    "BatchStartRecommendationsRequestRequestTypeDef",
     "CancelReplicationTaskAssessmentRunResponseTypeDef",
     "DeleteReplicationTaskAssessmentRunResponseTypeDef",
     "DescribeReplicationTaskAssessmentRunsResponseTypeDef",
@@ -263,11 +280,13 @@ __all__ = (
     "DescribeReplicationSubnetGroupsResponseTypeDef",
     "ModifyReplicationSubnetGroupResponseTypeDef",
     "ReplicationInstanceTypeDef",
+    "RecommendationTypeDef",
     "CreateReplicationInstanceResponseTypeDef",
     "DeleteReplicationInstanceResponseTypeDef",
     "DescribeReplicationInstancesResponseTypeDef",
     "ModifyReplicationInstanceResponseTypeDef",
     "RebootReplicationInstanceResponseTypeDef",
+    "DescribeRecommendationsResponseTypeDef",
 )
 
 AccountQuotaTypeDef = TypedDict(
@@ -318,6 +337,16 @@ AvailabilityZoneTypeDef = TypedDict(
     total=False,
 )
 
+BatchStartRecommendationsErrorEntryTypeDef = TypedDict(
+    "BatchStartRecommendationsErrorEntryTypeDef",
+    {
+        "DatabaseId": str,
+        "Message": str,
+        "Code": str,
+    },
+    total=False,
+)
+
 CancelReplicationTaskAssessmentRunMessageRequestTypeDef = TypedDict(
     "CancelReplicationTaskAssessmentRunMessageRequestTypeDef",
     {
@@ -501,6 +530,7 @@ KafkaSettingsTypeDef = TypedDict(
         "SaslUsername": str,
         "SaslPassword": str,
         "NoHexPrefix": bool,
+        "SaslMechanism": KafkaSaslMechanismType,
     },
     total=False,
 )
@@ -540,6 +570,8 @@ MicrosoftSQLServerSettingsTypeDef = TypedDict(
         "SecretsManagerAccessRoleArn": str,
         "SecretsManagerSecretId": str,
         "TrimSpaceInChar": bool,
+        "TlogAccessMode": TlogAccessModeType,
+        "ForceLobLookup": bool,
     },
     total=False,
 )
@@ -654,6 +686,7 @@ OracleSettingsTypeDef = TypedDict(
         "SecretsManagerOracleAsmAccessRoleArn": str,
         "SecretsManagerOracleAsmSecretId": str,
         "TrimSpaceInChar": bool,
+        "ConvertTimestampWithZoneToUTC": bool,
     },
     total=False,
 )
@@ -680,6 +713,7 @@ PostgreSQLSettingsTypeDef = TypedDict(
         "SecretsManagerAccessRoleArn": str,
         "SecretsManagerSecretId": str,
         "TrimSpaceInChar": bool,
+        "MapBooleanAsBoolean": bool,
     },
     total=False,
 )
@@ -741,6 +775,7 @@ RedshiftSettingsTypeDef = TypedDict(
         "WriteBufferSize": int,
         "SecretsManagerAccessRoleArn": str,
         "SecretsManagerSecretId": str,
+        "MapBooleanAsBoolean": bool,
     },
     total=False,
 )
@@ -788,6 +823,7 @@ S3SettingsTypeDef = TypedDict(
         "DatePartitionTimezone": str,
         "AddTrailingPaddingCharacter": bool,
         "ExpectedBucketOwner": str,
+        "GlueCatalogGeneration": bool,
     },
     total=False,
 )
@@ -1115,7 +1151,20 @@ OrderableReplicationInstanceTypeDef = TypedDict(
         "DefaultAllocatedStorage": int,
         "IncludedAllocatedStorage": int,
         "AvailabilityZones": List[str],
-        "ReleaseStatus": Literal["beta"],
+        "ReleaseStatus": ReleaseStatusValuesType,
+    },
+    total=False,
+)
+
+LimitationTypeDef = TypedDict(
+    "LimitationTypeDef",
+    {
+        "DatabaseId": str,
+        "EngineName": str,
+        "Name": str,
+        "Description": str,
+        "Impact": str,
+        "Type": str,
     },
     total=False,
 )
@@ -1399,6 +1448,34 @@ PendingMaintenanceActionTypeDef = TypedDict(
     total=False,
 )
 
+RdsConfigurationTypeDef = TypedDict(
+    "RdsConfigurationTypeDef",
+    {
+        "EngineEdition": str,
+        "InstanceType": str,
+        "InstanceVcpu": float,
+        "InstanceMemory": float,
+        "StorageType": str,
+        "StorageSize": int,
+        "StorageIops": int,
+        "DeploymentOption": str,
+    },
+    total=False,
+)
+
+RdsRequirementsTypeDef = TypedDict(
+    "RdsRequirementsTypeDef",
+    {
+        "EngineEdition": str,
+        "InstanceVcpu": float,
+        "InstanceMemory": float,
+        "StorageSize": int,
+        "StorageIops": int,
+        "DeploymentOption": str,
+    },
+    total=False,
+)
+
 _RequiredRebootReplicationInstanceMessageRequestTypeDef = TypedDict(
     "_RequiredRebootReplicationInstanceMessageRequestTypeDef",
     {
@@ -1422,6 +1499,14 @@ class RebootReplicationInstanceMessageRequestTypeDef(
     pass
 
 
+RecommendationSettingsTypeDef = TypedDict(
+    "RecommendationSettingsTypeDef",
+    {
+        "InstanceSizingType": str,
+        "WorkloadType": str,
+    },
+)
+
 RefreshSchemasMessageRequestTypeDef = TypedDict(
     "RefreshSchemasMessageRequestTypeDef",
     {
@@ -1838,6 +1923,14 @@ SubnetTypeDef = TypedDict(
     total=False,
 )
 
+BatchStartRecommendationsResponseTypeDef = TypedDict(
+    "BatchStartRecommendationsResponseTypeDef",
+    {
+        "ErrorEntries": List[BatchStartRecommendationsErrorEntryTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 DeleteCertificateResponseTypeDef = TypedDict(
     "DeleteCertificateResponseTypeDef",
     {
@@ -2229,6 +2322,26 @@ DescribePendingMaintenanceActionsMessageRequestTypeDef = TypedDict(
     total=False,
 )
 
+DescribeRecommendationLimitationsRequestRequestTypeDef = TypedDict(
+    "DescribeRecommendationLimitationsRequestRequestTypeDef",
+    {
+        "Filters": Sequence[FilterTypeDef],
+        "MaxRecords": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+DescribeRecommendationsRequestRequestTypeDef = TypedDict(
+    "DescribeRecommendationsRequestRequestTypeDef",
+    {
+        "Filters": Sequence[FilterTypeDef],
+        "MaxRecords": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
 DescribeReplicationInstancesMessageRequestTypeDef = TypedDict(
     "DescribeReplicationInstancesMessageRequestTypeDef",
     {
@@ -2609,6 +2722,15 @@ DescribeOrderableReplicationInstancesResponseTypeDef = TypedDict(
     },
 )
 
+DescribeRecommendationLimitationsResponseTypeDef = TypedDict(
+    "DescribeRecommendationLimitationsResponseTypeDef",
+    {
+        "NextToken": str,
+        "Limitations": List[LimitationTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 DescribeRefreshSchemasStatusResponseTypeDef = TypedDict(
     "DescribeRefreshSchemasStatusResponseTypeDef",
     {
@@ -2673,6 +2795,31 @@ ResourcePendingMaintenanceActionsTypeDef = TypedDict(
     total=False,
 )
 
+RdsRecommendationTypeDef = TypedDict(
+    "RdsRecommendationTypeDef",
+    {
+        "RequirementsToTarget": RdsRequirementsTypeDef,
+        "TargetConfiguration": RdsConfigurationTypeDef,
+    },
+    total=False,
+)
+
+StartRecommendationsRequestEntryTypeDef = TypedDict(
+    "StartRecommendationsRequestEntryTypeDef",
+    {
+        "DatabaseId": str,
+        "Settings": RecommendationSettingsTypeDef,
+    },
+)
+
+StartRecommendationsRequestRequestTypeDef = TypedDict(
+    "StartRecommendationsRequestRequestTypeDef",
+    {
+        "DatabaseId": str,
+        "Settings": RecommendationSettingsTypeDef,
+    },
+)
+
 _RequiredReloadTablesMessageRequestTypeDef = TypedDict(
     "_RequiredReloadTablesMessageRequestTypeDef",
     {
@@ -2837,6 +2984,22 @@ DescribePendingMaintenanceActionsResponseTypeDef = TypedDict(
     },
 )
 
+RecommendationDataTypeDef = TypedDict(
+    "RecommendationDataTypeDef",
+    {
+        "RdsEngine": RdsRecommendationTypeDef,
+    },
+    total=False,
+)
+
+BatchStartRecommendationsRequestRequestTypeDef = TypedDict(
+    "BatchStartRecommendationsRequestRequestTypeDef",
+    {
+        "Data": Sequence[StartRecommendationsRequestEntryTypeDef],
+    },
+    total=False,
+)
+
 CancelReplicationTaskAssessmentRunResponseTypeDef = TypedDict(
     "CancelReplicationTaskAssessmentRunResponseTypeDef",
     {
@@ -3001,6 +3164,20 @@ ReplicationInstanceTypeDef = TypedDict(
     total=False,
 )
 
+RecommendationTypeDef = TypedDict(
+    "RecommendationTypeDef",
+    {
+        "DatabaseId": str,
+        "EngineName": str,
+        "CreatedDate": str,
+        "Status": str,
+        "Preferred": bool,
+        "Settings": RecommendationSettingsTypeDef,
+        "Data": RecommendationDataTypeDef,
+    },
+    total=False,
+)
+
 CreateReplicationInstanceResponseTypeDef = TypedDict(
     "CreateReplicationInstanceResponseTypeDef",
     {
@@ -3041,3 +3218,12 @@ RebootReplicationInstanceResponseTypeDef = TypedDict(
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
+
+DescribeRecommendationsResponseTypeDef = TypedDict(
+    "DescribeRecommendationsResponseTypeDef",
+    {
+        "NextToken": str,
+        "Recommendations": List[RecommendationTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
