@@ -35,7 +35,7 @@ Usage::
 """
 from typing import Sequence
 
-from botocore.waiter import Waiter as Boto3Waiter
+from botocore.waiter import Waiter
 
 from .type_defs import FilterTypeDef, WaiterConfigTypeDef
 
@@ -51,7 +51,7 @@ __all__ = (
 )
 
 
-class EndpointDeletedWaiter(Boto3Waiter):
+class EndpointDeletedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Waiter.EndpointDeleted)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/waiters/#endpointdeletedwaiter)
@@ -71,7 +71,7 @@ class EndpointDeletedWaiter(Boto3Waiter):
         """
 
 
-class ReplicationInstanceAvailableWaiter(Boto3Waiter):
+class ReplicationInstanceAvailableWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationInstanceAvailable)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/waiters/#replicationinstanceavailablewaiter)
@@ -91,7 +91,7 @@ class ReplicationInstanceAvailableWaiter(Boto3Waiter):
         """
 
 
-class ReplicationInstanceDeletedWaiter(Boto3Waiter):
+class ReplicationInstanceDeletedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationInstanceDeleted)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/waiters/#replicationinstancedeletedwaiter)
@@ -111,7 +111,7 @@ class ReplicationInstanceDeletedWaiter(Boto3Waiter):
         """
 
 
-class ReplicationTaskDeletedWaiter(Boto3Waiter):
+class ReplicationTaskDeletedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskDeleted)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/waiters/#replicationtaskdeletedwaiter)
@@ -132,7 +132,7 @@ class ReplicationTaskDeletedWaiter(Boto3Waiter):
         """
 
 
-class ReplicationTaskReadyWaiter(Boto3Waiter):
+class ReplicationTaskReadyWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskReady)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/waiters/#replicationtaskreadywaiter)
@@ -153,7 +153,7 @@ class ReplicationTaskReadyWaiter(Boto3Waiter):
         """
 
 
-class ReplicationTaskRunningWaiter(Boto3Waiter):
+class ReplicationTaskRunningWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskRunning)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/waiters/#replicationtaskrunningwaiter)
@@ -174,7 +174,7 @@ class ReplicationTaskRunningWaiter(Boto3Waiter):
         """
 
 
-class ReplicationTaskStoppedWaiter(Boto3Waiter):
+class ReplicationTaskStoppedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Waiter.ReplicationTaskStopped)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/waiters/#replicationtaskstoppedwaiter)
@@ -195,7 +195,7 @@ class ReplicationTaskStoppedWaiter(Boto3Waiter):
         """
 
 
-class TestConnectionSucceedsWaiter(Boto3Waiter):
+class TestConnectionSucceedsWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dms.html#DatabaseMigrationService.Waiter.TestConnectionSucceeds)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dms/waiters/#testconnectionsucceedswaiter)
